<?php
namespace EMS\PortalFuncionario\Geral\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\{ Request, Response };
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Doctrine\ORM\EntityManager;

use EMS\PortalFuncionario\Geral\Services\SolicitacaoService;

class SolicitacaoController {
    /** @var SolicitacaoService */
    protected $solicitacaoService;

    /** @var EntityManager */
    protected $entityManager;

    public function __construct(
        EntityManager $entityManager,
        SolicitacaoService $solicitacaoService
    ) {
        $this->entityManager        = $entityManager;
        $this->solicitacaoService   = $solicitacaoService;
    }

    public function getSolicitacao(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();
            $comunicados = $this->solicitacaoService->getSolicitacao(
                $params['NRVINCULOM'],
                $params['NRORG'],
                $params['CDOPERADOR']
            );
            $response->addDataSet(new DataSet('data', $comunicados));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function getItemSolicitacao(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $params = $request->getParameters();

            $nrOrg = (int) $params['NRORG'];
            $nrSolicitacao = (int) $params['NRSOLICITACAO'];

            $dataSet = $this->solicitacaoService->getItemSolicitacao($nrOrg, $nrSolicitacao);

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
}
